@@ -61,10 +61,11 @@ sub jq_warm_thrusters {
       backend => setting('workers')->{'BACKEND'},
     }, { for => 'update' }, )->update({ actionset => [] });
 
+    my $deferrals = setting('workers')->{'max_deferrals'} - 1;
     $rs->search({
       backend => setting('workers')->{'BACKEND'},
-      deferrals => { '>' => 0 },
-    }, { for => 'update' }, )->update({ deferrals => \'deferrals - 1' });
+      deferrals => { '>' => $deferrals },
+    }, { for => 'update' }, )->update({ deferrals => $deferrals });
 
     $rs->search({
       backend => setting('workers')->{'BACKEND'},
